#!/usr/bin/env groovy
/*
* Licensed Materials - Property of IBM Corp.
* IBM AnthillPro
* (c) Copyright IBM Corporation 2002, 2013. All Rights Reserved.
*
* U.S. Government Users Restricted Rights - Use, duplication or disclosure restricted by
* GSA ADP Schedule Contract with IBM Corp.
*/


import com.urbancode.anthill3.*;

File workDir = new File('.').canonicalFile
boolean isWindows = (System.getProperty('os.name') =~ /(?i)windows/).find()

AHPTool ahpTool = new AHPTool();

def stepProps = ahpTool.getStepProperties();

// Repo
String scriptFile = stepProps['scriptFile'] ?: '';
String scriptBody = stepProps['scriptBody'] ?: '';
String groovyFlgs = stepProps['groovyFlags'] ?: '';
String groovyArgs = stepProps['groovyArgs'] ?: '';
String groovyHome = stepProps['groovyHome'] ?: '';

if (!scriptFile) {
    File f = null;
    // use shutdown hook to handle cleanup for abort signal
    Runtime.runtime.addShutdownHook({f?.delete();});
    f = File.createTempFile('groovy_', '.groovy');
    scriptFile = f.absolutePath;
}

if (scriptBody) {
    new File(scriptFile).text = scriptBody;
}

def groovyExe = 'groovy'
if (groovyHome) {
  def gHome = new File(groovyHome);
  def gBin = new File(gHome, 'bin');
  groovyExe = new File(gBin, 'groovy').absolutePath;
}
if (isWindows) {
  groovyExe += '.bat';
}

def cmd = [];
cmd << groovyExe;
groovyFlgs.eachLine{
    if (it) {
        cmd << it;
    }
}
cmd << scriptFile;
groovyArgs.eachLine{
    if (it) {
        cmd << it;
    }
}

def cmdHelper = new CommandHelper(workDir);
cmdHelper.runCommand('Run Groovy', cmd);

